from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.ApplicationModel.Store.Preview
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Security.Authentication.Web.Core
import win32more.Windows.Security.Credentials
import win32more.Windows.Storage.Streams
import win32more.Windows.System
import win32more.Windows.UI.Xaml
import win32more.Windows.Win32.System.WinRT
class DeliveryOptimizationDownloadMode(Enum, Int32):
    Simple = 0
    HttpOnly = 1
    Lan = 2
    Group = 3
    Internet = 4
    Bypass = 5
class DeliveryOptimizationDownloadModeSource(Enum, Int32):
    Default = 0
    Policy = 1
class DeliveryOptimizationSettings(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Store.Preview.IDeliveryOptimizationSettings
    _classid_ = 'Windows.ApplicationModel.Store.Preview.DeliveryOptimizationSettings'
    @winrt_mixinmethod
    def get_DownloadMode(self: win32more.Windows.ApplicationModel.Store.Preview.IDeliveryOptimizationSettings) -> win32more.Windows.ApplicationModel.Store.Preview.DeliveryOptimizationDownloadMode: ...
    @winrt_mixinmethod
    def get_DownloadModeSource(self: win32more.Windows.ApplicationModel.Store.Preview.IDeliveryOptimizationSettings) -> win32more.Windows.ApplicationModel.Store.Preview.DeliveryOptimizationDownloadModeSource: ...
    @winrt_classmethod
    def GetCurrentSettings(cls: win32more.Windows.ApplicationModel.Store.Preview.IDeliveryOptimizationSettingsStatics) -> win32more.Windows.ApplicationModel.Store.Preview.DeliveryOptimizationSettings: ...
    DownloadMode = property(get_DownloadMode, None)
    DownloadModeSource = property(get_DownloadModeSource, None)
class IDeliveryOptimizationSettings(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Store.Preview.IDeliveryOptimizationSettings'
    _iid_ = Guid('{1810fda0-e853-565e-b874-7a8a7b9a0e0f}')
    @winrt_commethod(6)
    def get_DownloadMode(self) -> win32more.Windows.ApplicationModel.Store.Preview.DeliveryOptimizationDownloadMode: ...
    @winrt_commethod(7)
    def get_DownloadModeSource(self) -> win32more.Windows.ApplicationModel.Store.Preview.DeliveryOptimizationDownloadModeSource: ...
    DownloadMode = property(get_DownloadMode, None)
    DownloadModeSource = property(get_DownloadModeSource, None)
class IDeliveryOptimizationSettingsStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Store.Preview.IDeliveryOptimizationSettingsStatics'
    _iid_ = Guid('{5c817caf-aed5-5999-b4c9-8c60898bc4f3}')
    @winrt_commethod(6)
    def GetCurrentSettings(self) -> win32more.Windows.ApplicationModel.Store.Preview.DeliveryOptimizationSettings: ...
class IStoreConfigurationStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Store.Preview.IStoreConfigurationStatics'
    _iid_ = Guid('{728f7fc0-8628-42ec-84a2-07780eb44d8b}')
    @winrt_commethod(6)
    def SetSystemConfiguration(self, catalogHardwareManufacturerId: WinRT_String, catalogStoreContentModifierId: WinRT_String, systemConfigurationExpiration: win32more.Windows.Foundation.DateTime, catalogHardwareDescriptor: WinRT_String) -> Void: ...
    @winrt_commethod(7)
    def SetMobileOperatorConfiguration(self, mobileOperatorId: WinRT_String, appDownloadLimitInMegabytes: UInt32, updateDownloadLimitInMegabytes: UInt32) -> Void: ...
    @winrt_commethod(8)
    def SetStoreWebAccountId(self, webAccountId: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def IsStoreWebAccountId(self, webAccountId: WinRT_String) -> Boolean: ...
    @winrt_commethod(10)
    def get_HardwareManufacturerInfo(self) -> win32more.Windows.ApplicationModel.Store.Preview.StoreHardwareManufacturerInfo: ...
    @winrt_commethod(11)
    def FilterUnsupportedSystemFeaturesAsync(self, systemFeatures: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.ApplicationModel.Store.Preview.StoreSystemFeature]) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Store.Preview.StoreSystemFeature]]: ...
    HardwareManufacturerInfo = property(get_HardwareManufacturerInfo, None)
class IStoreConfigurationStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Store.Preview.IStoreConfigurationStatics2'
    _iid_ = Guid('{657c4595-c8b7-4fe9-9f4c-4d71027d347e}')
    @winrt_commethod(6)
    def get_PurchasePromptingPolicy(self) -> win32more.Windows.Foundation.IReference[UInt32]: ...
    @winrt_commethod(7)
    def put_PurchasePromptingPolicy(self, value: win32more.Windows.Foundation.IReference[UInt32]) -> Void: ...
    PurchasePromptingPolicy = property(get_PurchasePromptingPolicy, put_PurchasePromptingPolicy)
class IStoreConfigurationStatics3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Store.Preview.IStoreConfigurationStatics3'
    _iid_ = Guid('{6d45f57c-f144-4cb5-9d3f-4eb05e30b6d3}')
    @winrt_commethod(6)
    def HasStoreWebAccount(self) -> Boolean: ...
    @winrt_commethod(7)
    def HasStoreWebAccountForUser(self, user: win32more.Windows.System.User) -> Boolean: ...
    @winrt_commethod(8)
    def GetStoreLogDataAsync(self, options: win32more.Windows.ApplicationModel.Store.Preview.StoreLogOptions) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.Streams.IRandomAccessStreamReference]: ...
    @winrt_commethod(9)
    def SetStoreWebAccountIdForUser(self, user: win32more.Windows.System.User, webAccountId: WinRT_String) -> Void: ...
    @winrt_commethod(10)
    def IsStoreWebAccountIdForUser(self, user: win32more.Windows.System.User, webAccountId: WinRT_String) -> Boolean: ...
    @winrt_commethod(11)
    def GetPurchasePromptingPolicyForUser(self, user: win32more.Windows.System.User) -> win32more.Windows.Foundation.IReference[UInt32]: ...
    @winrt_commethod(12)
    def SetPurchasePromptingPolicyForUser(self, user: win32more.Windows.System.User, value: win32more.Windows.Foundation.IReference[UInt32]) -> Void: ...
class IStoreConfigurationStatics4(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Store.Preview.IStoreConfigurationStatics4'
    _iid_ = Guid('{20ff56d2-4ee3-4cf0-9b12-552c03310f75}')
    @winrt_commethod(6)
    def GetStoreWebAccountId(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def GetStoreWebAccountIdForUser(self, user: win32more.Windows.System.User) -> WinRT_String: ...
    @winrt_commethod(8)
    def SetEnterpriseStoreWebAccountId(self, webAccountId: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def SetEnterpriseStoreWebAccountIdForUser(self, user: win32more.Windows.System.User, webAccountId: WinRT_String) -> Void: ...
    @winrt_commethod(10)
    def GetEnterpriseStoreWebAccountId(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def GetEnterpriseStoreWebAccountIdForUser(self, user: win32more.Windows.System.User) -> WinRT_String: ...
    @winrt_commethod(12)
    def ShouldRestrictToEnterpriseStoreOnly(self) -> Boolean: ...
    @winrt_commethod(13)
    def ShouldRestrictToEnterpriseStoreOnlyForUser(self, user: win32more.Windows.System.User) -> Boolean: ...
class IStoreConfigurationStatics5(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Store.Preview.IStoreConfigurationStatics5'
    _iid_ = Guid('{f7613191-8fa9-49db-822b-0160e7e4e5c5}')
    @winrt_commethod(6)
    def IsPinToDesktopSupported(self) -> Boolean: ...
    @winrt_commethod(7)
    def IsPinToTaskbarSupported(self) -> Boolean: ...
    @winrt_commethod(8)
    def IsPinToStartSupported(self) -> Boolean: ...
    @winrt_commethod(9)
    def PinToDesktop(self, appPackageFamilyName: WinRT_String) -> Void: ...
    @winrt_commethod(10)
    def PinToDesktopForUser(self, user: win32more.Windows.System.User, appPackageFamilyName: WinRT_String) -> Void: ...
class IStoreHardwareManufacturerInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Store.Preview.IStoreHardwareManufacturerInfo'
    _iid_ = Guid('{f292dc08-c654-43ac-a21f-34801c9d3388}')
    @winrt_commethod(6)
    def get_HardwareManufacturerId(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_StoreContentModifierId(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_ModelName(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def get_ManufacturerName(self) -> WinRT_String: ...
    HardwareManufacturerId = property(get_HardwareManufacturerId, None)
    ManufacturerName = property(get_ManufacturerName, None)
    ModelName = property(get_ModelName, None)
    StoreContentModifierId = property(get_StoreContentModifierId, None)
class IStorePreview(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Store.Preview.IStorePreview'
    _iid_ = Guid('{8a157241-840e-49a9-bc01-5d5b01fbc8e9}')
    @winrt_commethod(6)
    def RequestProductPurchaseByProductIdAndSkuIdAsync(self, productId: WinRT_String, skuId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.ApplicationModel.Store.Preview.StorePreviewPurchaseResults]: ...
    @winrt_commethod(7)
    def LoadAddOnProductInfosAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Store.Preview.StorePreviewProductInfo]]: ...
class IStorePreviewProductInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Store.Preview.IStorePreviewProductInfo'
    _iid_ = Guid('{1937dbb3-6c01-4c9d-85cd-5babaac2b351}')
    @winrt_commethod(6)
    def get_ProductId(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_ProductType(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_Title(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def get_Description(self) -> WinRT_String: ...
    @winrt_commethod(10)
    def get_SkuInfoList(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Store.Preview.StorePreviewSkuInfo]: ...
    Description = property(get_Description, None)
    ProductId = property(get_ProductId, None)
    ProductType = property(get_ProductType, None)
    SkuInfoList = property(get_SkuInfoList, None)
    Title = property(get_Title, None)
class IStorePreviewPurchaseResults(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Store.Preview.IStorePreviewPurchaseResults'
    _iid_ = Guid('{b0daaed1-d6c5-4e53-a043-fba0d8e61231}')
    @winrt_commethod(6)
    def get_ProductPurchaseStatus(self) -> win32more.Windows.ApplicationModel.Store.Preview.StorePreviewProductPurchaseStatus: ...
    ProductPurchaseStatus = property(get_ProductPurchaseStatus, None)
class IStorePreviewSkuInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Store.Preview.IStorePreviewSkuInfo'
    _iid_ = Guid('{81fd76e2-0b26-48d9-98ce-27461c669d6c}')
    @winrt_commethod(6)
    def get_ProductId(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_SkuId(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_SkuType(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def get_Title(self) -> WinRT_String: ...
    @winrt_commethod(10)
    def get_Description(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def get_CustomDeveloperData(self) -> WinRT_String: ...
    @winrt_commethod(12)
    def get_CurrencyCode(self) -> WinRT_String: ...
    @winrt_commethod(13)
    def get_FormattedListPrice(self) -> WinRT_String: ...
    @winrt_commethod(14)
    def get_ExtendedData(self) -> WinRT_String: ...
    CurrencyCode = property(get_CurrencyCode, None)
    CustomDeveloperData = property(get_CustomDeveloperData, None)
    Description = property(get_Description, None)
    ExtendedData = property(get_ExtendedData, None)
    FormattedListPrice = property(get_FormattedListPrice, None)
    ProductId = property(get_ProductId, None)
    SkuId = property(get_SkuId, None)
    SkuType = property(get_SkuType, None)
    Title = property(get_Title, None)
class IWebAuthenticationCoreManagerHelper(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Store.Preview.IWebAuthenticationCoreManagerHelper'
    _iid_ = Guid('{06a50525-e715-4123-9276-9d6f865ba55f}')
    @winrt_commethod(6)
    def RequestTokenWithUIElementHostingAsync(self, request: win32more.Windows.Security.Authentication.Web.Core.WebTokenRequest, uiElement: win32more.Windows.UI.Xaml.UIElement) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Security.Authentication.Web.Core.WebTokenRequestResult]: ...
    @winrt_commethod(7)
    def RequestTokenWithUIElementHostingAndWebAccountAsync(self, request: win32more.Windows.Security.Authentication.Web.Core.WebTokenRequest, webAccount: win32more.Windows.Security.Credentials.WebAccount, uiElement: win32more.Windows.UI.Xaml.UIElement) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Security.Authentication.Web.Core.WebTokenRequestResult]: ...
class _StoreConfiguration_Meta_(ComPtr.__class__):
    pass
class StoreConfiguration(ComPtr, metaclass=_StoreConfiguration_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Store.Preview.StoreConfiguration'
    @winrt_classmethod
    def IsPinToDesktopSupported(cls: win32more.Windows.ApplicationModel.Store.Preview.IStoreConfigurationStatics5) -> Boolean: ...
    @winrt_classmethod
    def IsPinToTaskbarSupported(cls: win32more.Windows.ApplicationModel.Store.Preview.IStoreConfigurationStatics5) -> Boolean: ...
    @winrt_classmethod
    def IsPinToStartSupported(cls: win32more.Windows.ApplicationModel.Store.Preview.IStoreConfigurationStatics5) -> Boolean: ...
    @winrt_classmethod
    def PinToDesktop(cls: win32more.Windows.ApplicationModel.Store.Preview.IStoreConfigurationStatics5, appPackageFamilyName: WinRT_String) -> Void: ...
    @winrt_classmethod
    def PinToDesktopForUser(cls: win32more.Windows.ApplicationModel.Store.Preview.IStoreConfigurationStatics5, user: win32more.Windows.System.User, appPackageFamilyName: WinRT_String) -> Void: ...
    @winrt_classmethod
    def GetStoreWebAccountId(cls: win32more.Windows.ApplicationModel.Store.Preview.IStoreConfigurationStatics4) -> WinRT_String: ...
    @winrt_classmethod
    def GetStoreWebAccountIdForUser(cls: win32more.Windows.ApplicationModel.Store.Preview.IStoreConfigurationStatics4, user: win32more.Windows.System.User) -> WinRT_String: ...
    @winrt_classmethod
    def SetEnterpriseStoreWebAccountId(cls: win32more.Windows.ApplicationModel.Store.Preview.IStoreConfigurationStatics4, webAccountId: WinRT_String) -> Void: ...
    @winrt_classmethod
    def SetEnterpriseStoreWebAccountIdForUser(cls: win32more.Windows.ApplicationModel.Store.Preview.IStoreConfigurationStatics4, user: win32more.Windows.System.User, webAccountId: WinRT_String) -> Void: ...
    @winrt_classmethod
    def GetEnterpriseStoreWebAccountId(cls: win32more.Windows.ApplicationModel.Store.Preview.IStoreConfigurationStatics4) -> WinRT_String: ...
    @winrt_classmethod
    def GetEnterpriseStoreWebAccountIdForUser(cls: win32more.Windows.ApplicationModel.Store.Preview.IStoreConfigurationStatics4, user: win32more.Windows.System.User) -> WinRT_String: ...
    @winrt_classmethod
    def ShouldRestrictToEnterpriseStoreOnly(cls: win32more.Windows.ApplicationModel.Store.Preview.IStoreConfigurationStatics4) -> Boolean: ...
    @winrt_classmethod
    def ShouldRestrictToEnterpriseStoreOnlyForUser(cls: win32more.Windows.ApplicationModel.Store.Preview.IStoreConfigurationStatics4, user: win32more.Windows.System.User) -> Boolean: ...
    @winrt_classmethod
    def HasStoreWebAccount(cls: win32more.Windows.ApplicationModel.Store.Preview.IStoreConfigurationStatics3) -> Boolean: ...
    @winrt_classmethod
    def HasStoreWebAccountForUser(cls: win32more.Windows.ApplicationModel.Store.Preview.IStoreConfigurationStatics3, user: win32more.Windows.System.User) -> Boolean: ...
    @winrt_classmethod
    def GetStoreLogDataAsync(cls: win32more.Windows.ApplicationModel.Store.Preview.IStoreConfigurationStatics3, options: win32more.Windows.ApplicationModel.Store.Preview.StoreLogOptions) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.Streams.IRandomAccessStreamReference]: ...
    @winrt_classmethod
    def SetStoreWebAccountIdForUser(cls: win32more.Windows.ApplicationModel.Store.Preview.IStoreConfigurationStatics3, user: win32more.Windows.System.User, webAccountId: WinRT_String) -> Void: ...
    @winrt_classmethod
    def IsStoreWebAccountIdForUser(cls: win32more.Windows.ApplicationModel.Store.Preview.IStoreConfigurationStatics3, user: win32more.Windows.System.User, webAccountId: WinRT_String) -> Boolean: ...
    @winrt_classmethod
    def GetPurchasePromptingPolicyForUser(cls: win32more.Windows.ApplicationModel.Store.Preview.IStoreConfigurationStatics3, user: win32more.Windows.System.User) -> win32more.Windows.Foundation.IReference[UInt32]: ...
    @winrt_classmethod
    def SetPurchasePromptingPolicyForUser(cls: win32more.Windows.ApplicationModel.Store.Preview.IStoreConfigurationStatics3, user: win32more.Windows.System.User, value: win32more.Windows.Foundation.IReference[UInt32]) -> Void: ...
    @winrt_classmethod
    def get_PurchasePromptingPolicy(cls: win32more.Windows.ApplicationModel.Store.Preview.IStoreConfigurationStatics2) -> win32more.Windows.Foundation.IReference[UInt32]: ...
    @winrt_classmethod
    def put_PurchasePromptingPolicy(cls: win32more.Windows.ApplicationModel.Store.Preview.IStoreConfigurationStatics2, value: win32more.Windows.Foundation.IReference[UInt32]) -> Void: ...
    @winrt_classmethod
    def SetSystemConfiguration(cls: win32more.Windows.ApplicationModel.Store.Preview.IStoreConfigurationStatics, catalogHardwareManufacturerId: WinRT_String, catalogStoreContentModifierId: WinRT_String, systemConfigurationExpiration: win32more.Windows.Foundation.DateTime, catalogHardwareDescriptor: WinRT_String) -> Void: ...
    @winrt_classmethod
    def SetMobileOperatorConfiguration(cls: win32more.Windows.ApplicationModel.Store.Preview.IStoreConfigurationStatics, mobileOperatorId: WinRT_String, appDownloadLimitInMegabytes: UInt32, updateDownloadLimitInMegabytes: UInt32) -> Void: ...
    @winrt_classmethod
    def SetStoreWebAccountId(cls: win32more.Windows.ApplicationModel.Store.Preview.IStoreConfigurationStatics, webAccountId: WinRT_String) -> Void: ...
    @winrt_classmethod
    def IsStoreWebAccountId(cls: win32more.Windows.ApplicationModel.Store.Preview.IStoreConfigurationStatics, webAccountId: WinRT_String) -> Boolean: ...
    @winrt_classmethod
    def get_HardwareManufacturerInfo(cls: win32more.Windows.ApplicationModel.Store.Preview.IStoreConfigurationStatics) -> win32more.Windows.ApplicationModel.Store.Preview.StoreHardwareManufacturerInfo: ...
    @winrt_classmethod
    def FilterUnsupportedSystemFeaturesAsync(cls: win32more.Windows.ApplicationModel.Store.Preview.IStoreConfigurationStatics, systemFeatures: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.ApplicationModel.Store.Preview.StoreSystemFeature]) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Store.Preview.StoreSystemFeature]]: ...
    _StoreConfiguration_Meta_.HardwareManufacturerInfo = property(get_HardwareManufacturerInfo, None)
    _StoreConfiguration_Meta_.PurchasePromptingPolicy = property(get_PurchasePromptingPolicy, put_PurchasePromptingPolicy)
class StoreHardwareManufacturerInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Store.Preview.IStoreHardwareManufacturerInfo
    _classid_ = 'Windows.ApplicationModel.Store.Preview.StoreHardwareManufacturerInfo'
    @winrt_mixinmethod
    def get_HardwareManufacturerId(self: win32more.Windows.ApplicationModel.Store.Preview.IStoreHardwareManufacturerInfo) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_StoreContentModifierId(self: win32more.Windows.ApplicationModel.Store.Preview.IStoreHardwareManufacturerInfo) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ModelName(self: win32more.Windows.ApplicationModel.Store.Preview.IStoreHardwareManufacturerInfo) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ManufacturerName(self: win32more.Windows.ApplicationModel.Store.Preview.IStoreHardwareManufacturerInfo) -> WinRT_String: ...
    HardwareManufacturerId = property(get_HardwareManufacturerId, None)
    ManufacturerName = property(get_ManufacturerName, None)
    ModelName = property(get_ModelName, None)
    StoreContentModifierId = property(get_StoreContentModifierId, None)
class StoreLogOptions(Enum, UInt32):
    None_ = 0
    TryElevate = 1
class StorePreview(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Store.Preview.StorePreview'
    @winrt_classmethod
    def RequestProductPurchaseByProductIdAndSkuIdAsync(cls: win32more.Windows.ApplicationModel.Store.Preview.IStorePreview, productId: WinRT_String, skuId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.ApplicationModel.Store.Preview.StorePreviewPurchaseResults]: ...
    @winrt_classmethod
    def LoadAddOnProductInfosAsync(cls: win32more.Windows.ApplicationModel.Store.Preview.IStorePreview) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Store.Preview.StorePreviewProductInfo]]: ...
class StorePreviewProductInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Store.Preview.IStorePreviewProductInfo
    _classid_ = 'Windows.ApplicationModel.Store.Preview.StorePreviewProductInfo'
    @winrt_mixinmethod
    def get_ProductId(self: win32more.Windows.ApplicationModel.Store.Preview.IStorePreviewProductInfo) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ProductType(self: win32more.Windows.ApplicationModel.Store.Preview.IStorePreviewProductInfo) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Title(self: win32more.Windows.ApplicationModel.Store.Preview.IStorePreviewProductInfo) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Windows.ApplicationModel.Store.Preview.IStorePreviewProductInfo) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_SkuInfoList(self: win32more.Windows.ApplicationModel.Store.Preview.IStorePreviewProductInfo) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Store.Preview.StorePreviewSkuInfo]: ...
    Description = property(get_Description, None)
    ProductId = property(get_ProductId, None)
    ProductType = property(get_ProductType, None)
    SkuInfoList = property(get_SkuInfoList, None)
    Title = property(get_Title, None)
class StorePreviewProductPurchaseStatus(Enum, Int32):
    Succeeded = 0
    AlreadyPurchased = 1
    NotFulfilled = 2
    NotPurchased = 3
class StorePreviewPurchaseResults(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Store.Preview.IStorePreviewPurchaseResults
    _classid_ = 'Windows.ApplicationModel.Store.Preview.StorePreviewPurchaseResults'
    @winrt_mixinmethod
    def get_ProductPurchaseStatus(self: win32more.Windows.ApplicationModel.Store.Preview.IStorePreviewPurchaseResults) -> win32more.Windows.ApplicationModel.Store.Preview.StorePreviewProductPurchaseStatus: ...
    ProductPurchaseStatus = property(get_ProductPurchaseStatus, None)
class StorePreviewSkuInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Store.Preview.IStorePreviewSkuInfo
    _classid_ = 'Windows.ApplicationModel.Store.Preview.StorePreviewSkuInfo'
    @winrt_mixinmethod
    def get_ProductId(self: win32more.Windows.ApplicationModel.Store.Preview.IStorePreviewSkuInfo) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_SkuId(self: win32more.Windows.ApplicationModel.Store.Preview.IStorePreviewSkuInfo) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_SkuType(self: win32more.Windows.ApplicationModel.Store.Preview.IStorePreviewSkuInfo) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Title(self: win32more.Windows.ApplicationModel.Store.Preview.IStorePreviewSkuInfo) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Windows.ApplicationModel.Store.Preview.IStorePreviewSkuInfo) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_CustomDeveloperData(self: win32more.Windows.ApplicationModel.Store.Preview.IStorePreviewSkuInfo) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_CurrencyCode(self: win32more.Windows.ApplicationModel.Store.Preview.IStorePreviewSkuInfo) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_FormattedListPrice(self: win32more.Windows.ApplicationModel.Store.Preview.IStorePreviewSkuInfo) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ExtendedData(self: win32more.Windows.ApplicationModel.Store.Preview.IStorePreviewSkuInfo) -> WinRT_String: ...
    CurrencyCode = property(get_CurrencyCode, None)
    CustomDeveloperData = property(get_CustomDeveloperData, None)
    Description = property(get_Description, None)
    ExtendedData = property(get_ExtendedData, None)
    FormattedListPrice = property(get_FormattedListPrice, None)
    ProductId = property(get_ProductId, None)
    SkuId = property(get_SkuId, None)
    SkuType = property(get_SkuType, None)
    Title = property(get_Title, None)
class StoreSystemFeature(Enum, Int32):
    ArchitectureX86 = 0
    ArchitectureX64 = 1
    ArchitectureArm = 2
    DirectX9 = 3
    DirectX10 = 4
    DirectX11 = 5
    D3D12HardwareFL11 = 6
    D3D12HardwareFL12 = 7
    Memory300MB = 8
    Memory750MB = 9
    Memory1GB = 10
    Memory2GB = 11
    CameraFront = 12
    CameraRear = 13
    Gyroscope = 14
    Hover = 15
    Magnetometer = 16
    Nfc = 17
    Resolution720P = 18
    ResolutionWvga = 19
    ResolutionWvgaOr720P = 20
    ResolutionWxga = 21
    ResolutionWvgaOrWxga = 22
    ResolutionWxgaOr720P = 23
    Memory4GB = 24
    Memory6GB = 25
    Memory8GB = 26
    Memory12GB = 27
    Memory16GB = 28
    Memory20GB = 29
    VideoMemory2GB = 30
    VideoMemory4GB = 31
    VideoMemory6GB = 32
    VideoMemory1GB = 33
    ArchitectureArm64 = 34
class WebAuthenticationCoreManagerHelper(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Store.Preview.WebAuthenticationCoreManagerHelper'
    @winrt_classmethod
    def RequestTokenWithUIElementHostingAsync(cls: win32more.Windows.ApplicationModel.Store.Preview.IWebAuthenticationCoreManagerHelper, request: win32more.Windows.Security.Authentication.Web.Core.WebTokenRequest, uiElement: win32more.Windows.UI.Xaml.UIElement) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Security.Authentication.Web.Core.WebTokenRequestResult]: ...
    @winrt_classmethod
    def RequestTokenWithUIElementHostingAndWebAccountAsync(cls: win32more.Windows.ApplicationModel.Store.Preview.IWebAuthenticationCoreManagerHelper, request: win32more.Windows.Security.Authentication.Web.Core.WebTokenRequest, webAccount: win32more.Windows.Security.Credentials.WebAccount, uiElement: win32more.Windows.UI.Xaml.UIElement) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Security.Authentication.Web.Core.WebTokenRequestResult]: ...


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Management.MobileDeviceManagementRegistration
MENROLL_E_DEVICE_MESSAGE_FORMAT_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2145910783
MENROLL_E_DEVICE_AUTHENTICATION_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2145910782
MENROLL_E_DEVICE_AUTHORIZATION_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2145910781
MENROLL_E_DEVICE_CERTIFICATEREQUEST_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2145910780
MENROLL_E_DEVICE_CONFIGMGRSERVER_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2145910779
MENROLL_E_DEVICE_INTERNALSERVICE_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2145910778
MENROLL_E_DEVICE_INVALIDSECURITY_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2145910777
MENROLL_E_DEVICE_UNKNOWN_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2145910776
MENROLL_E_ENROLLMENT_IN_PROGRESS: win32more.Windows.Win32.Foundation.HRESULT = -2145910775
MENROLL_E_DEVICE_ALREADY_ENROLLED: win32more.Windows.Win32.Foundation.HRESULT = -2145910774
MENROLL_E_DISCOVERY_SEC_CERT_DATE_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -2145910771
MENROLL_E_PASSWORD_NEEDED: win32more.Windows.Win32.Foundation.HRESULT = -2145910770
MENROLL_E_WAB_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2145910769
MENROLL_E_CONNECTIVITY: win32more.Windows.Win32.Foundation.HRESULT = -2145910768
MENROLL_E_INVALIDSSLCERT: win32more.Windows.Win32.Foundation.HRESULT = -2145910766
MENROLL_E_DEVICECAPREACHED: win32more.Windows.Win32.Foundation.HRESULT = -2145910765
MENROLL_E_DEVICENOTSUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2145910764
MENROLL_E_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2145910763
MENROLL_E_NOTELIGIBLETORENEW: win32more.Windows.Win32.Foundation.HRESULT = -2145910762
MENROLL_E_INMAINTENANCE: win32more.Windows.Win32.Foundation.HRESULT = -2145910761
MENROLL_E_USER_LICENSE: win32more.Windows.Win32.Foundation.HRESULT = -2145910760
MENROLL_E_ENROLLMENTDATAINVALID: win32more.Windows.Win32.Foundation.HRESULT = -2145910759
MENROLL_E_INSECUREREDIRECT: win32more.Windows.Win32.Foundation.HRESULT = -2145910758
MENROLL_E_PLATFORM_WRONG_STATE: win32more.Windows.Win32.Foundation.HRESULT = -2145910757
MENROLL_E_PLATFORM_LICENSE_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2145910756
MENROLL_E_PLATFORM_UNKNOWN_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2145910755
MENROLL_E_PROV_CSP_CERTSTORE: win32more.Windows.Win32.Foundation.HRESULT = -2145910754
MENROLL_E_PROV_CSP_W7: win32more.Windows.Win32.Foundation.HRESULT = -2145910753
MENROLL_E_PROV_CSP_DMCLIENT: win32more.Windows.Win32.Foundation.HRESULT = -2145910752
MENROLL_E_PROV_CSP_PFW: win32more.Windows.Win32.Foundation.HRESULT = -2145910751
MENROLL_E_PROV_CSP_MISC: win32more.Windows.Win32.Foundation.HRESULT = -2145910750
MENROLL_E_PROV_UNKNOWN: win32more.Windows.Win32.Foundation.HRESULT = -2145910749
MENROLL_E_PROV_SSLCERTNOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = -2145910748
MENROLL_E_PROV_CSP_APPMGMT: win32more.Windows.Win32.Foundation.HRESULT = -2145910747
MENROLL_E_DEVICE_MANAGEMENT_BLOCKED: win32more.Windows.Win32.Foundation.HRESULT = -2145910746
MENROLL_E_CERTPOLICY_PRIVATEKEYCREATION_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2145910745
MENROLL_E_CERTAUTH_FAILED_TO_FIND_CERT: win32more.Windows.Win32.Foundation.HRESULT = -2145910744
MENROLL_E_EMPTY_MESSAGE: win32more.Windows.Win32.Foundation.HRESULT = -2145910743
MENROLL_E_USER_CANCELLED: win32more.Windows.Win32.Foundation.HRESULT = -2145910736
MENROLL_E_MDM_NOT_CONFIGURED: win32more.Windows.Win32.Foundation.HRESULT = -2145910735
MENROLL_E_CUSTOMSERVERERROR: win32more.Windows.Win32.Foundation.HRESULT = -2145910734
MDM_REGISTRATION_FACILITY_CODE: UInt32 = 25
DEVICE_ENROLLER_FACILITY_CODE: UInt32 = 24
MREGISTER_E_DEVICE_MESSAGE_FORMAT_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2145845247
MREGISTER_E_DEVICE_AUTHENTICATION_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2145845246
MREGISTER_E_DEVICE_AUTHORIZATION_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2145845245
MREGISTER_E_DEVICE_CERTIFCATEREQUEST_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2145845244
MENROLL_E_DEVICE_CERTIFCATEREQUEST_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2145910780
MREGISTER_E_DEVICE_CONFIGMGRSERVER_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2145845243
MREGISTER_E_DEVICE_INTERNALSERVICE_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2145845242
MREGISTER_E_DEVICE_INVALIDSECURITY_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2145845241
MREGISTER_E_DEVICE_UNKNOWN_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2145845240
MREGISTER_E_REGISTRATION_IN_PROGRESS: win32more.Windows.Win32.Foundation.HRESULT = -2145845239
MREGISTER_E_DEVICE_ALREADY_REGISTERED: win32more.Windows.Win32.Foundation.HRESULT = -2145845238
MREGISTER_E_DEVICE_NOT_REGISTERED: win32more.Windows.Win32.Foundation.HRESULT = -2145845237
MENROLL_E_DEVICE_NOT_ENROLLED: win32more.Windows.Win32.Foundation.HRESULT = -2145910773
MREGISTER_E_DISCOVERY_REDIRECTED: win32more.Windows.Win32.Foundation.HRESULT = -2145845236
MREGISTER_E_DEVICE_NOT_AD_REGISTERED_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2145845235
MREGISTER_E_DISCOVERY_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2145845234
MENROLL_E_NOTSUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2145910763
MENROLL_E_USERLICENSE: win32more.Windows.Win32.Foundation.HRESULT = -2145910760
MENROLL_E_USER_CANCELED: win32more.Windows.Win32.Foundation.HRESULT = -2145910742
DEVICEREGISTRATIONTYPE_MDM_ONLY: UInt32 = 0
DEVICEREGISTRATIONTYPE_MAM: UInt32 = 5
DEVICEREGISTRATIONTYPE_MDM_DEVICEWIDE_WITH_AAD: UInt32 = 6
DEVICEREGISTRATIONTYPE_MDM_USERSPECIFIC_WITH_AAD: UInt32 = 13
@winfunctype('MDMRegistration.dll')
def GetDeviceRegistrationInfo(DeviceInformationClass: win32more.Windows.Win32.Management.MobileDeviceManagementRegistration.REGISTRATION_INFORMATION_CLASS, ppDeviceRegistrationInfo: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('MDMRegistration.dll')
def IsDeviceRegisteredWithManagement(pfIsDeviceRegisteredWithManagement: POINTER(win32more.Windows.Win32.Foundation.BOOL), cchUPN: UInt32, pszUPN: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('MDMRegistration.dll')
def IsManagementRegistrationAllowed(pfIsManagementRegistrationAllowed: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('MDMRegistration.dll')
def IsMdmUxWithoutAadAllowed(isEnrollmentAllowed: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('MDMRegistration.dll')
def SetManagedExternally(IsManagedExternally: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('MDMRegistration.dll')
def DiscoverManagementService(pszUPN: win32more.Windows.Win32.Foundation.PWSTR, ppMgmtInfo: POINTER(POINTER(win32more.Windows.Win32.Management.MobileDeviceManagementRegistration.MANAGEMENT_SERVICE_INFO))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('MDMRegistration.dll')
def RegisterDeviceWithManagementUsingAADCredentials(UserToken: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('MDMRegistration.dll')
def RegisterDeviceWithManagementUsingAADDeviceCredentials() -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('MDMRegistration.dll')
def RegisterDeviceWithManagementUsingAADDeviceCredentials2(MDMApplicationID: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('MDMRegistration.dll')
def RegisterDeviceWithManagement(pszUPN: win32more.Windows.Win32.Foundation.PWSTR, ppszMDMServiceUri: win32more.Windows.Win32.Foundation.PWSTR, ppzsAccessToken: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('MDMRegistration.dll')
def UnregisterDeviceWithManagement(enrollmentID: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('MDMRegistration.dll')
def GetDeviceManagementConfigInfo(providerID: win32more.Windows.Win32.Foundation.PWSTR, configStringBufferLength: POINTER(UInt32), configString: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('MDMRegistration.dll')
def SetDeviceManagementConfigInfo(providerID: win32more.Windows.Win32.Foundation.PWSTR, configString: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('MDMRegistration.dll')
def GetManagementAppHyperlink(cchHyperlink: UInt32, pszHyperlink: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('MDMRegistration.dll')
def DiscoverManagementServiceEx(pszUPN: win32more.Windows.Win32.Foundation.PWSTR, pszDiscoveryServiceCandidate: win32more.Windows.Win32.Foundation.PWSTR, ppMgmtInfo: POINTER(POINTER(win32more.Windows.Win32.Management.MobileDeviceManagementRegistration.MANAGEMENT_SERVICE_INFO))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('MDMLocalManagement.dll')
def RegisterDeviceWithLocalManagement(alreadyRegistered: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('MDMLocalManagement.dll')
def ApplyLocalManagementSyncML(syncMLRequest: win32more.Windows.Win32.Foundation.PWSTR, syncMLResult: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('MDMLocalManagement.dll')
def UnregisterDeviceWithLocalManagement() -> win32more.Windows.Win32.Foundation.HRESULT: ...
class MANAGEMENT_REGISTRATION_INFO(Structure):
    fDeviceRegisteredWithManagement: win32more.Windows.Win32.Foundation.BOOL
    dwDeviceRegistionKind: UInt32
    pszUPN: win32more.Windows.Win32.Foundation.PWSTR
    pszMDMServiceUri: win32more.Windows.Win32.Foundation.PWSTR
class MANAGEMENT_SERVICE_INFO(Structure):
    pszMDMServiceUri: win32more.Windows.Win32.Foundation.PWSTR
    pszAuthenticationUri: win32more.Windows.Win32.Foundation.PWSTR
REGISTRATION_INFORMATION_CLASS = Int32
DeviceRegistrationBasicInfo: win32more.Windows.Win32.Management.MobileDeviceManagementRegistration.REGISTRATION_INFORMATION_CLASS = 1
MaxDeviceInfoClass: win32more.Windows.Win32.Management.MobileDeviceManagementRegistration.REGISTRATION_INFORMATION_CLASS = 2


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Security
import win32more.Windows.Win32.System.Memory
FILE_CACHE_MAX_HARD_ENABLE: UInt32 = 1
FILE_CACHE_MAX_HARD_DISABLE: UInt32 = 2
FILE_CACHE_MIN_HARD_ENABLE: UInt32 = 4
FILE_CACHE_MIN_HARD_DISABLE: UInt32 = 8
MEHC_PATROL_SCRUBBER_PRESENT: UInt32 = 1
@winfunctype('KERNEL32.dll')
def HeapCreate(flOptions: win32more.Windows.Win32.System.Memory.HEAP_FLAGS, dwInitialSize: UIntPtr, dwMaximumSize: UIntPtr) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('KERNEL32.dll')
def HeapDestroy(hHeap: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def HeapAlloc(hHeap: win32more.Windows.Win32.Foundation.HANDLE, dwFlags: win32more.Windows.Win32.System.Memory.HEAP_FLAGS, dwBytes: UIntPtr) -> VoidPtr: ...
@winfunctype('KERNEL32.dll')
def HeapReAlloc(hHeap: win32more.Windows.Win32.Foundation.HANDLE, dwFlags: win32more.Windows.Win32.System.Memory.HEAP_FLAGS, lpMem: VoidPtr, dwBytes: UIntPtr) -> VoidPtr: ...
@winfunctype('KERNEL32.dll')
def HeapFree(hHeap: win32more.Windows.Win32.Foundation.HANDLE, dwFlags: win32more.Windows.Win32.System.Memory.HEAP_FLAGS, lpMem: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def HeapSize(hHeap: win32more.Windows.Win32.Foundation.HANDLE, dwFlags: win32more.Windows.Win32.System.Memory.HEAP_FLAGS, lpMem: VoidPtr) -> UIntPtr: ...
@winfunctype('KERNEL32.dll')
def GetProcessHeap() -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('KERNEL32.dll')
def HeapCompact(hHeap: win32more.Windows.Win32.Foundation.HANDLE, dwFlags: win32more.Windows.Win32.System.Memory.HEAP_FLAGS) -> UIntPtr: ...
@winfunctype('KERNEL32.dll')
def HeapSetInformation(HeapHandle: win32more.Windows.Win32.Foundation.HANDLE, HeapInformationClass: win32more.Windows.Win32.System.Memory.HEAP_INFORMATION_CLASS, HeapInformation: VoidPtr, HeapInformationLength: UIntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def HeapValidate(hHeap: win32more.Windows.Win32.Foundation.HANDLE, dwFlags: win32more.Windows.Win32.System.Memory.HEAP_FLAGS, lpMem: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def HeapSummary(hHeap: win32more.Windows.Win32.Foundation.HANDLE, dwFlags: UInt32, lpSummary: POINTER(win32more.Windows.Win32.System.Memory.HEAP_SUMMARY)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetProcessHeaps(NumberOfHeaps: UInt32, ProcessHeaps: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> UInt32: ...
@winfunctype('KERNEL32.dll')
def HeapLock(hHeap: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def HeapUnlock(hHeap: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def HeapWalk(hHeap: win32more.Windows.Win32.Foundation.HANDLE, lpEntry: POINTER(win32more.Windows.Win32.System.Memory.PROCESS_HEAP_ENTRY)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def HeapQueryInformation(HeapHandle: win32more.Windows.Win32.Foundation.HANDLE, HeapInformationClass: win32more.Windows.Win32.System.Memory.HEAP_INFORMATION_CLASS, HeapInformation: VoidPtr, HeapInformationLength: UIntPtr, ReturnLength: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def VirtualAlloc(lpAddress: VoidPtr, dwSize: UIntPtr, flAllocationType: win32more.Windows.Win32.System.Memory.VIRTUAL_ALLOCATION_TYPE, flProtect: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS) -> VoidPtr: ...
@winfunctype('KERNEL32.dll')
def VirtualProtect(lpAddress: VoidPtr, dwSize: UIntPtr, flNewProtect: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS, lpflOldProtect: POINTER(win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def VirtualFree(lpAddress: VoidPtr, dwSize: UIntPtr, dwFreeType: win32more.Windows.Win32.System.Memory.VIRTUAL_FREE_TYPE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def VirtualQuery(lpAddress: VoidPtr, lpBuffer: POINTER(win32more.Windows.Win32.System.Memory.MEMORY_BASIC_INFORMATION), dwLength: UIntPtr) -> UIntPtr: ...
@winfunctype('KERNEL32.dll')
def VirtualAllocEx(hProcess: win32more.Windows.Win32.Foundation.HANDLE, lpAddress: VoidPtr, dwSize: UIntPtr, flAllocationType: win32more.Windows.Win32.System.Memory.VIRTUAL_ALLOCATION_TYPE, flProtect: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS) -> VoidPtr: ...
@winfunctype('KERNEL32.dll')
def VirtualProtectEx(hProcess: win32more.Windows.Win32.Foundation.HANDLE, lpAddress: VoidPtr, dwSize: UIntPtr, flNewProtect: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS, lpflOldProtect: POINTER(win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def VirtualQueryEx(hProcess: win32more.Windows.Win32.Foundation.HANDLE, lpAddress: VoidPtr, lpBuffer: POINTER(win32more.Windows.Win32.System.Memory.MEMORY_BASIC_INFORMATION), dwLength: UIntPtr) -> UIntPtr: ...
@winfunctype('KERNEL32.dll')
def CreateFileMappingW(hFile: win32more.Windows.Win32.Foundation.HANDLE, lpFileMappingAttributes: POINTER(win32more.Windows.Win32.Security.SECURITY_ATTRIBUTES), flProtect: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS, dwMaximumSizeHigh: UInt32, dwMaximumSizeLow: UInt32, lpName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HANDLE: ...
CreateFileMapping = UnicodeAlias('CreateFileMappingW')
@winfunctype('KERNEL32.dll')
def OpenFileMappingW(dwDesiredAccess: UInt32, bInheritHandle: win32more.Windows.Win32.Foundation.BOOL, lpName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HANDLE: ...
OpenFileMapping = UnicodeAlias('OpenFileMappingW')
@winfunctype('KERNEL32.dll')
def MapViewOfFile(hFileMappingObject: win32more.Windows.Win32.Foundation.HANDLE, dwDesiredAccess: win32more.Windows.Win32.System.Memory.FILE_MAP, dwFileOffsetHigh: UInt32, dwFileOffsetLow: UInt32, dwNumberOfBytesToMap: UIntPtr) -> win32more.Windows.Win32.System.Memory.MEMORY_MAPPED_VIEW_ADDRESS: ...
@winfunctype('KERNEL32.dll')
def MapViewOfFileEx(hFileMappingObject: win32more.Windows.Win32.Foundation.HANDLE, dwDesiredAccess: win32more.Windows.Win32.System.Memory.FILE_MAP, dwFileOffsetHigh: UInt32, dwFileOffsetLow: UInt32, dwNumberOfBytesToMap: UIntPtr, lpBaseAddress: VoidPtr) -> win32more.Windows.Win32.System.Memory.MEMORY_MAPPED_VIEW_ADDRESS: ...
@winfunctype('KERNEL32.dll')
def VirtualFreeEx(hProcess: win32more.Windows.Win32.Foundation.HANDLE, lpAddress: VoidPtr, dwSize: UIntPtr, dwFreeType: win32more.Windows.Win32.System.Memory.VIRTUAL_FREE_TYPE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def FlushViewOfFile(lpBaseAddress: VoidPtr, dwNumberOfBytesToFlush: UIntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def UnmapViewOfFile(lpBaseAddress: win32more.Windows.Win32.System.Memory.MEMORY_MAPPED_VIEW_ADDRESS) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetLargePageMinimum() -> UIntPtr: ...
@winfunctype('KERNEL32.dll')
def GetProcessWorkingSetSizeEx(hProcess: win32more.Windows.Win32.Foundation.HANDLE, lpMinimumWorkingSetSize: POINTER(UIntPtr), lpMaximumWorkingSetSize: POINTER(UIntPtr), Flags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def SetProcessWorkingSetSizeEx(hProcess: win32more.Windows.Win32.Foundation.HANDLE, dwMinimumWorkingSetSize: UIntPtr, dwMaximumWorkingSetSize: UIntPtr, Flags: win32more.Windows.Win32.System.Memory.SETPROCESSWORKINGSETSIZEEX_FLAGS) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def VirtualLock(lpAddress: VoidPtr, dwSize: UIntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def VirtualUnlock(lpAddress: VoidPtr, dwSize: UIntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetWriteWatch(dwFlags: UInt32, lpBaseAddress: VoidPtr, dwRegionSize: UIntPtr, lpAddresses: POINTER(VoidPtr), lpdwCount: POINTER(UIntPtr), lpdwGranularity: POINTER(UInt32)) -> UInt32: ...
@winfunctype('KERNEL32.dll')
def ResetWriteWatch(lpBaseAddress: VoidPtr, dwRegionSize: UIntPtr) -> UInt32: ...
@winfunctype('KERNEL32.dll')
def CreateMemoryResourceNotification(NotificationType: win32more.Windows.Win32.System.Memory.MEMORY_RESOURCE_NOTIFICATION_TYPE) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('KERNEL32.dll')
def QueryMemoryResourceNotification(ResourceNotificationHandle: win32more.Windows.Win32.Foundation.HANDLE, ResourceState: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetSystemFileCacheSize(lpMinimumFileCacheSize: POINTER(UIntPtr), lpMaximumFileCacheSize: POINTER(UIntPtr), lpFlags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def SetSystemFileCacheSize(MinimumFileCacheSize: UIntPtr, MaximumFileCacheSize: UIntPtr, Flags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def CreateFileMappingNumaW(hFile: win32more.Windows.Win32.Foundation.HANDLE, lpFileMappingAttributes: POINTER(win32more.Windows.Win32.Security.SECURITY_ATTRIBUTES), flProtect: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS, dwMaximumSizeHigh: UInt32, dwMaximumSizeLow: UInt32, lpName: win32more.Windows.Win32.Foundation.PWSTR, nndPreferred: UInt32) -> win32more.Windows.Win32.Foundation.HANDLE: ...
CreateFileMappingNuma = UnicodeAlias('CreateFileMappingNumaW')
@winfunctype('KERNEL32.dll')
def PrefetchVirtualMemory(hProcess: win32more.Windows.Win32.Foundation.HANDLE, NumberOfEntries: UIntPtr, VirtualAddresses: POINTER(win32more.Windows.Win32.System.Memory.WIN32_MEMORY_RANGE_ENTRY), Flags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def CreateFileMappingFromApp(hFile: win32more.Windows.Win32.Foundation.HANDLE, SecurityAttributes: POINTER(win32more.Windows.Win32.Security.SECURITY_ATTRIBUTES), PageProtection: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS, MaximumSize: UInt64, Name: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('KERNEL32.dll')
def MapViewOfFileFromApp(hFileMappingObject: win32more.Windows.Win32.Foundation.HANDLE, DesiredAccess: win32more.Windows.Win32.System.Memory.FILE_MAP, FileOffset: UInt64, NumberOfBytesToMap: UIntPtr) -> win32more.Windows.Win32.System.Memory.MEMORY_MAPPED_VIEW_ADDRESS: ...
@winfunctype('KERNEL32.dll')
def UnmapViewOfFileEx(BaseAddress: win32more.Windows.Win32.System.Memory.MEMORY_MAPPED_VIEW_ADDRESS, UnmapFlags: win32more.Windows.Win32.System.Memory.UNMAP_VIEW_OF_FILE_FLAGS) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def AllocateUserPhysicalPages(hProcess: win32more.Windows.Win32.Foundation.HANDLE, NumberOfPages: POINTER(UIntPtr), PageArray: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def FreeUserPhysicalPages(hProcess: win32more.Windows.Win32.Foundation.HANDLE, NumberOfPages: POINTER(UIntPtr), PageArray: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def MapUserPhysicalPages(VirtualAddress: VoidPtr, NumberOfPages: UIntPtr, PageArray: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def AllocateUserPhysicalPagesNuma(hProcess: win32more.Windows.Win32.Foundation.HANDLE, NumberOfPages: POINTER(UIntPtr), PageArray: POINTER(UIntPtr), nndPreferred: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def VirtualAllocExNuma(hProcess: win32more.Windows.Win32.Foundation.HANDLE, lpAddress: VoidPtr, dwSize: UIntPtr, flAllocationType: win32more.Windows.Win32.System.Memory.VIRTUAL_ALLOCATION_TYPE, flProtect: UInt32, nndPreferred: UInt32) -> VoidPtr: ...
@winfunctype('KERNEL32.dll')
def GetMemoryErrorHandlingCapabilities(Capabilities: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def RegisterBadMemoryNotification(Callback: win32more.Windows.Win32.System.Memory.PBAD_MEMORY_CALLBACK_ROUTINE) -> VoidPtr: ...
@winfunctype('KERNEL32.dll')
def UnregisterBadMemoryNotification(RegistrationHandle: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def OfferVirtualMemory(VirtualAddress: VoidPtr, Size: UIntPtr, Priority: win32more.Windows.Win32.System.Memory.OFFER_PRIORITY) -> UInt32: ...
@winfunctype('KERNEL32.dll')
def ReclaimVirtualMemory(VirtualAddress: VoidPtr, Size: UIntPtr) -> UInt32: ...
@winfunctype('KERNEL32.dll')
def DiscardVirtualMemory(VirtualAddress: VoidPtr, Size: UIntPtr) -> UInt32: ...
@winfunctype('api-ms-win-core-memory-l1-1-3.dll')
def SetProcessValidCallTargets(hProcess: win32more.Windows.Win32.Foundation.HANDLE, VirtualAddress: VoidPtr, RegionSize: UIntPtr, NumberOfOffsets: UInt32, OffsetInformation: POINTER(win32more.Windows.Win32.System.Memory.CFG_CALL_TARGET_INFO)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('api-ms-win-core-memory-l1-1-7.dll')
def SetProcessValidCallTargetsForMappedView(Process: win32more.Windows.Win32.Foundation.HANDLE, VirtualAddress: VoidPtr, RegionSize: UIntPtr, NumberOfOffsets: UInt32, OffsetInformation: POINTER(win32more.Windows.Win32.System.Memory.CFG_CALL_TARGET_INFO), Section: win32more.Windows.Win32.Foundation.HANDLE, ExpectedFileOffset: UInt64) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('api-ms-win-core-memory-l1-1-3.dll')
def VirtualAllocFromApp(BaseAddress: VoidPtr, Size: UIntPtr, AllocationType: win32more.Windows.Win32.System.Memory.VIRTUAL_ALLOCATION_TYPE, Protection: UInt32) -> VoidPtr: ...
@winfunctype('api-ms-win-core-memory-l1-1-3.dll')
def VirtualProtectFromApp(Address: VoidPtr, Size: UIntPtr, NewProtection: UInt32, OldProtection: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('api-ms-win-core-memory-l1-1-3.dll')
def OpenFileMappingFromApp(DesiredAccess: UInt32, InheritHandle: win32more.Windows.Win32.Foundation.BOOL, Name: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('api-ms-win-core-memory-l1-1-4.dll')
def QueryVirtualMemoryInformation(Process: win32more.Windows.Win32.Foundation.HANDLE, VirtualAddress: VoidPtr, MemoryInformationClass: win32more.Windows.Win32.System.Memory.WIN32_MEMORY_INFORMATION_CLASS, MemoryInformation: VoidPtr, MemoryInformationSize: UIntPtr, ReturnSize: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('api-ms-win-core-memory-l1-1-5.dll')
def MapViewOfFileNuma2(FileMappingHandle: win32more.Windows.Win32.Foundation.HANDLE, ProcessHandle: win32more.Windows.Win32.Foundation.HANDLE, Offset: UInt64, BaseAddress: VoidPtr, ViewSize: UIntPtr, AllocationType: UInt32, PageProtection: UInt32, PreferredNode: UInt32) -> win32more.Windows.Win32.System.Memory.MEMORY_MAPPED_VIEW_ADDRESS: ...
@winfunctype('api-ms-win-core-memory-l1-1-5.dll')
def UnmapViewOfFile2(Process: win32more.Windows.Win32.Foundation.HANDLE, BaseAddress: win32more.Windows.Win32.System.Memory.MEMORY_MAPPED_VIEW_ADDRESS, UnmapFlags: win32more.Windows.Win32.System.Memory.UNMAP_VIEW_OF_FILE_FLAGS) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('api-ms-win-core-memory-l1-1-5.dll')
def VirtualUnlockEx(Process: win32more.Windows.Win32.Foundation.HANDLE, Address: VoidPtr, Size: UIntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('api-ms-win-core-memory-l1-1-6.dll')
def VirtualAlloc2(Process: win32more.Windows.Win32.Foundation.HANDLE, BaseAddress: VoidPtr, Size: UIntPtr, AllocationType: win32more.Windows.Win32.System.Memory.VIRTUAL_ALLOCATION_TYPE, PageProtection: UInt32, ExtendedParameters: POINTER(win32more.Windows.Win32.System.Memory.MEM_EXTENDED_PARAMETER), ParameterCount: UInt32) -> VoidPtr: ...
@winfunctype('api-ms-win-core-memory-l1-1-6.dll')
def MapViewOfFile3(FileMapping: win32more.Windows.Win32.Foundation.HANDLE, Process: win32more.Windows.Win32.Foundation.HANDLE, BaseAddress: VoidPtr, Offset: UInt64, ViewSize: UIntPtr, AllocationType: win32more.Windows.Win32.System.Memory.VIRTUAL_ALLOCATION_TYPE, PageProtection: UInt32, ExtendedParameters: POINTER(win32more.Windows.Win32.System.Memory.MEM_EXTENDED_PARAMETER), ParameterCount: UInt32) -> win32more.Windows.Win32.System.Memory.MEMORY_MAPPED_VIEW_ADDRESS: ...
@winfunctype('api-ms-win-core-memory-l1-1-6.dll')
def VirtualAlloc2FromApp(Process: win32more.Windows.Win32.Foundation.HANDLE, BaseAddress: VoidPtr, Size: UIntPtr, AllocationType: win32more.Windows.Win32.System.Memory.VIRTUAL_ALLOCATION_TYPE, PageProtection: UInt32, ExtendedParameters: POINTER(win32more.Windows.Win32.System.Memory.MEM_EXTENDED_PARAMETER), ParameterCount: UInt32) -> VoidPtr: ...
@winfunctype('api-ms-win-core-memory-l1-1-6.dll')
def MapViewOfFile3FromApp(FileMapping: win32more.Windows.Win32.Foundation.HANDLE, Process: win32more.Windows.Win32.Foundation.HANDLE, BaseAddress: VoidPtr, Offset: UInt64, ViewSize: UIntPtr, AllocationType: win32more.Windows.Win32.System.Memory.VIRTUAL_ALLOCATION_TYPE, PageProtection: UInt32, ExtendedParameters: POINTER(win32more.Windows.Win32.System.Memory.MEM_EXTENDED_PARAMETER), ParameterCount: UInt32) -> win32more.Windows.Win32.System.Memory.MEMORY_MAPPED_VIEW_ADDRESS: ...
@winfunctype('api-ms-win-core-memory-l1-1-7.dll')
def CreateFileMapping2(File: win32more.Windows.Win32.Foundation.HANDLE, SecurityAttributes: POINTER(win32more.Windows.Win32.Security.SECURITY_ATTRIBUTES), DesiredAccess: UInt32, PageProtection: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS, AllocationAttributes: UInt32, MaximumSize: UInt64, Name: win32more.Windows.Win32.Foundation.PWSTR, ExtendedParameters: POINTER(win32more.Windows.Win32.System.Memory.MEM_EXTENDED_PARAMETER), ParameterCount: UInt32) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('api-ms-win-core-memory-l1-1-8.dll')
def AllocateUserPhysicalPages2(ObjectHandle: win32more.Windows.Win32.Foundation.HANDLE, NumberOfPages: POINTER(UIntPtr), PageArray: POINTER(UIntPtr), ExtendedParameters: POINTER(win32more.Windows.Win32.System.Memory.MEM_EXTENDED_PARAMETER), ExtendedParameterCount: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('api-ms-win-core-memory-l1-1-8.dll')
def OpenDedicatedMemoryPartition(Partition: win32more.Windows.Win32.Foundation.HANDLE, DedicatedMemoryTypeId: UInt64, DesiredAccess: UInt32, InheritHandle: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('api-ms-win-core-memory-l1-1-8.dll')
def QueryPartitionInformation(Partition: win32more.Windows.Win32.Foundation.HANDLE, PartitionInformationClass: win32more.Windows.Win32.System.Memory.WIN32_MEMORY_PARTITION_INFORMATION_CLASS, PartitionInformation: VoidPtr, PartitionInformationLength: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def RtlCompareMemory(Source1: VoidPtr, Source2: VoidPtr, Length: UIntPtr) -> UIntPtr: ...
@winfunctype('ntdll.dll')
def RtlCrc32(Buffer: VoidPtr, Size: UIntPtr, InitialCrc: UInt32) -> UInt32: ...
@winfunctype('ntdll.dll')
def RtlCrc64(Buffer: VoidPtr, Size: UIntPtr, InitialCrc: UInt64) -> UInt64: ...
@winfunctype('ntdll.dll')
def RtlIsZeroMemory(Buffer: VoidPtr, Length: UIntPtr) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
@winfunctype('KERNEL32.dll')
def GlobalAlloc(uFlags: win32more.Windows.Win32.System.Memory.GLOBAL_ALLOC_FLAGS, dwBytes: UIntPtr) -> win32more.Windows.Win32.Foundation.HGLOBAL: ...
@winfunctype('KERNEL32.dll')
def GlobalReAlloc(hMem: win32more.Windows.Win32.Foundation.HGLOBAL, dwBytes: UIntPtr, uFlags: UInt32) -> win32more.Windows.Win32.Foundation.HGLOBAL: ...
@winfunctype('KERNEL32.dll')
def GlobalSize(hMem: win32more.Windows.Win32.Foundation.HGLOBAL) -> UIntPtr: ...
@winfunctype('KERNEL32.dll')
def GlobalUnlock(hMem: win32more.Windows.Win32.Foundation.HGLOBAL) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GlobalLock(hMem: win32more.Windows.Win32.Foundation.HGLOBAL) -> VoidPtr: ...
@winfunctype('KERNEL32.dll')
def GlobalFlags(hMem: win32more.Windows.Win32.Foundation.HGLOBAL) -> UInt32: ...
@winfunctype('KERNEL32.dll')
def GlobalHandle(pMem: VoidPtr) -> win32more.Windows.Win32.Foundation.HGLOBAL: ...
@winfunctype('KERNEL32.dll')
def LocalAlloc(uFlags: win32more.Windows.Win32.System.Memory.LOCAL_ALLOC_FLAGS, uBytes: UIntPtr) -> win32more.Windows.Win32.Foundation.HLOCAL: ...
@winfunctype('KERNEL32.dll')
def LocalReAlloc(hMem: win32more.Windows.Win32.Foundation.HLOCAL, uBytes: UIntPtr, uFlags: UInt32) -> win32more.Windows.Win32.Foundation.HLOCAL: ...
@winfunctype('KERNEL32.dll')
def LocalLock(hMem: win32more.Windows.Win32.Foundation.HLOCAL) -> VoidPtr: ...
@winfunctype('KERNEL32.dll')
def LocalHandle(pMem: VoidPtr) -> win32more.Windows.Win32.Foundation.HLOCAL: ...
@winfunctype('KERNEL32.dll')
def LocalUnlock(hMem: win32more.Windows.Win32.Foundation.HLOCAL) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def LocalSize(hMem: win32more.Windows.Win32.Foundation.HLOCAL) -> UIntPtr: ...
@winfunctype('KERNEL32.dll')
def LocalFlags(hMem: win32more.Windows.Win32.Foundation.HLOCAL) -> UInt32: ...
@winfunctype('KERNEL32.dll')
def CreateFileMappingA(hFile: win32more.Windows.Win32.Foundation.HANDLE, lpFileMappingAttributes: POINTER(win32more.Windows.Win32.Security.SECURITY_ATTRIBUTES), flProtect: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS, dwMaximumSizeHigh: UInt32, dwMaximumSizeLow: UInt32, lpName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('KERNEL32.dll')
def CreateFileMappingNumaA(hFile: win32more.Windows.Win32.Foundation.HANDLE, lpFileMappingAttributes: POINTER(win32more.Windows.Win32.Security.SECURITY_ATTRIBUTES), flProtect: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS, dwMaximumSizeHigh: UInt32, dwMaximumSizeLow: UInt32, lpName: win32more.Windows.Win32.Foundation.PSTR, nndPreferred: UInt32) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('KERNEL32.dll')
def OpenFileMappingA(dwDesiredAccess: UInt32, bInheritHandle: win32more.Windows.Win32.Foundation.BOOL, lpName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('KERNEL32.dll')
def MapViewOfFileExNuma(hFileMappingObject: win32more.Windows.Win32.Foundation.HANDLE, dwDesiredAccess: win32more.Windows.Win32.System.Memory.FILE_MAP, dwFileOffsetHigh: UInt32, dwFileOffsetLow: UInt32, dwNumberOfBytesToMap: UIntPtr, lpBaseAddress: VoidPtr, nndPreferred: UInt32) -> win32more.Windows.Win32.System.Memory.MEMORY_MAPPED_VIEW_ADDRESS: ...
@winfunctype('KERNEL32.dll')
def IsBadReadPtr(lp: VoidPtr, ucb: UIntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def IsBadWritePtr(lp: VoidPtr, ucb: UIntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def IsBadCodePtr(lpfn: win32more.Windows.Win32.Foundation.FARPROC) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def IsBadStringPtrA(lpsz: win32more.Windows.Win32.Foundation.PSTR, ucchMax: UIntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def IsBadStringPtrW(lpsz: win32more.Windows.Win32.Foundation.PWSTR, ucchMax: UIntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
IsBadStringPtr = UnicodeAlias('IsBadStringPtrW')
@winfunctype('KERNEL32.dll')
def MapUserPhysicalPagesScatter(VirtualAddresses: POINTER(VoidPtr), NumberOfPages: UIntPtr, PageArray: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def AddSecureMemoryCacheCallback(pfnCallBack: win32more.Windows.Win32.System.Memory.PSECURE_MEMORY_CACHE_CALLBACK) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def RemoveSecureMemoryCacheCallback(pfnCallBack: win32more.Windows.Win32.System.Memory.PSECURE_MEMORY_CACHE_CALLBACK) -> win32more.Windows.Win32.Foundation.BOOL: ...
AtlThunkData_t = IntPtr
class CFG_CALL_TARGET_INFO(Structure):
    Offset: UIntPtr
    Flags: UIntPtr
FILE_MAP = UInt32
FILE_MAP_WRITE: win32more.Windows.Win32.System.Memory.FILE_MAP = 2
FILE_MAP_READ: win32more.Windows.Win32.System.Memory.FILE_MAP = 4
FILE_MAP_ALL_ACCESS: win32more.Windows.Win32.System.Memory.FILE_MAP = 983071
FILE_MAP_EXECUTE: win32more.Windows.Win32.System.Memory.FILE_MAP = 32
FILE_MAP_COPY: win32more.Windows.Win32.System.Memory.FILE_MAP = 1
FILE_MAP_RESERVE: win32more.Windows.Win32.System.Memory.FILE_MAP = 2147483648
FILE_MAP_TARGETS_INVALID: win32more.Windows.Win32.System.Memory.FILE_MAP = 1073741824
FILE_MAP_LARGE_PAGES: win32more.Windows.Win32.System.Memory.FILE_MAP = 536870912
GLOBAL_ALLOC_FLAGS = UInt32
GHND: win32more.Windows.Win32.System.Memory.GLOBAL_ALLOC_FLAGS = 66
GMEM_FIXED: win32more.Windows.Win32.System.Memory.GLOBAL_ALLOC_FLAGS = 0
GMEM_MOVEABLE: win32more.Windows.Win32.System.Memory.GLOBAL_ALLOC_FLAGS = 2
GMEM_ZEROINIT: win32more.Windows.Win32.System.Memory.GLOBAL_ALLOC_FLAGS = 64
GPTR: win32more.Windows.Win32.System.Memory.GLOBAL_ALLOC_FLAGS = 64
HEAP_FLAGS = UInt32
HEAP_NONE: win32more.Windows.Win32.System.Memory.HEAP_FLAGS = 0
HEAP_NO_SERIALIZE: win32more.Windows.Win32.System.Memory.HEAP_FLAGS = 1
HEAP_GROWABLE: win32more.Windows.Win32.System.Memory.HEAP_FLAGS = 2
HEAP_GENERATE_EXCEPTIONS: win32more.Windows.Win32.System.Memory.HEAP_FLAGS = 4
HEAP_ZERO_MEMORY: win32more.Windows.Win32.System.Memory.HEAP_FLAGS = 8
HEAP_REALLOC_IN_PLACE_ONLY: win32more.Windows.Win32.System.Memory.HEAP_FLAGS = 16
HEAP_TAIL_CHECKING_ENABLED: win32more.Windows.Win32.System.Memory.HEAP_FLAGS = 32
HEAP_FREE_CHECKING_ENABLED: win32more.Windows.Win32.System.Memory.HEAP_FLAGS = 64
HEAP_DISABLE_COALESCE_ON_FREE: win32more.Windows.Win32.System.Memory.HEAP_FLAGS = 128
HEAP_CREATE_ALIGN_16: win32more.Windows.Win32.System.Memory.HEAP_FLAGS = 65536
HEAP_CREATE_ENABLE_TRACING: win32more.Windows.Win32.System.Memory.HEAP_FLAGS = 131072
HEAP_CREATE_ENABLE_EXECUTE: win32more.Windows.Win32.System.Memory.HEAP_FLAGS = 262144
HEAP_MAXIMUM_TAG: win32more.Windows.Win32.System.Memory.HEAP_FLAGS = 4095
HEAP_PSEUDO_TAG_FLAG: win32more.Windows.Win32.System.Memory.HEAP_FLAGS = 32768
HEAP_TAG_SHIFT: win32more.Windows.Win32.System.Memory.HEAP_FLAGS = 18
HEAP_CREATE_SEGMENT_HEAP: win32more.Windows.Win32.System.Memory.HEAP_FLAGS = 256
HEAP_CREATE_HARDENED: win32more.Windows.Win32.System.Memory.HEAP_FLAGS = 512
HEAP_INFORMATION_CLASS = Int32
HeapCompatibilityInformation: win32more.Windows.Win32.System.Memory.HEAP_INFORMATION_CLASS = 0
HeapEnableTerminationOnCorruption: win32more.Windows.Win32.System.Memory.HEAP_INFORMATION_CLASS = 1
HeapOptimizeResources: win32more.Windows.Win32.System.Memory.HEAP_INFORMATION_CLASS = 3
HeapTag: win32more.Windows.Win32.System.Memory.HEAP_INFORMATION_CLASS = 7
class HEAP_SUMMARY(Structure):
    cb: UInt32
    cbAllocated: UIntPtr
    cbCommitted: UIntPtr
    cbReserved: UIntPtr
    cbMaxReserve: UIntPtr
LOCAL_ALLOC_FLAGS = UInt32
LHND: win32more.Windows.Win32.System.Memory.LOCAL_ALLOC_FLAGS = 66
LMEM_FIXED: win32more.Windows.Win32.System.Memory.LOCAL_ALLOC_FLAGS = 0
LMEM_MOVEABLE: win32more.Windows.Win32.System.Memory.LOCAL_ALLOC_FLAGS = 2
LMEM_ZEROINIT: win32more.Windows.Win32.System.Memory.LOCAL_ALLOC_FLAGS = 64
LPTR: win32more.Windows.Win32.System.Memory.LOCAL_ALLOC_FLAGS = 64
NONZEROLHND: win32more.Windows.Win32.System.Memory.LOCAL_ALLOC_FLAGS = 2
NONZEROLPTR: win32more.Windows.Win32.System.Memory.LOCAL_ALLOC_FLAGS = 0
if ARCH in 'X64,ARM64':
    class MEMORY_BASIC_INFORMATION(Structure):
        BaseAddress: VoidPtr
        AllocationBase: VoidPtr
        AllocationProtect: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS
        PartitionId: UInt16
        RegionSize: UIntPtr
        State: win32more.Windows.Win32.System.Memory.VIRTUAL_ALLOCATION_TYPE
        Protect: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS
        Type: win32more.Windows.Win32.System.Memory.PAGE_TYPE
elif ARCH in 'X86':
    class MEMORY_BASIC_INFORMATION(Structure):
        BaseAddress: VoidPtr
        AllocationBase: VoidPtr
        AllocationProtect: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS
        RegionSize: UIntPtr
        State: win32more.Windows.Win32.System.Memory.VIRTUAL_ALLOCATION_TYPE
        Protect: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS
        Type: win32more.Windows.Win32.System.Memory.PAGE_TYPE
class MEMORY_BASIC_INFORMATION32(Structure):
    BaseAddress: UInt32
    AllocationBase: UInt32
    AllocationProtect: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS
    RegionSize: UInt32
    State: win32more.Windows.Win32.System.Memory.VIRTUAL_ALLOCATION_TYPE
    Protect: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS
    Type: win32more.Windows.Win32.System.Memory.PAGE_TYPE
class MEMORY_BASIC_INFORMATION64(Structure):
    BaseAddress: UInt64
    AllocationBase: UInt64
    AllocationProtect: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS
    __alignment1: UInt32
    RegionSize: UInt64
    State: win32more.Windows.Win32.System.Memory.VIRTUAL_ALLOCATION_TYPE
    Protect: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS
    Type: win32more.Windows.Win32.System.Memory.PAGE_TYPE
    __alignment2: UInt32
class MEMORY_MAPPED_VIEW_ADDRESS(Structure):
    Value: VoidPtr
class MEMORY_PARTITION_DEDICATED_MEMORY_ATTRIBUTE(Structure):
    Type: win32more.Windows.Win32.System.Memory.MEM_DEDICATED_ATTRIBUTE_TYPE
    Reserved: UInt32
    Value: UInt64
class MEMORY_PARTITION_DEDICATED_MEMORY_INFORMATION(Structure):
    NextEntryOffset: UInt32
    SizeOfInformation: UInt32
    Flags: UInt32
    AttributesOffset: UInt32
    AttributeCount: UInt32
    Reserved: UInt32
    TypeId: UInt64
MEMORY_RESOURCE_NOTIFICATION_TYPE = Int32
LowMemoryResourceNotification: win32more.Windows.Win32.System.Memory.MEMORY_RESOURCE_NOTIFICATION_TYPE = 0
HighMemoryResourceNotification: win32more.Windows.Win32.System.Memory.MEMORY_RESOURCE_NOTIFICATION_TYPE = 1
class MEM_ADDRESS_REQUIREMENTS(Structure):
    LowestStartingAddress: VoidPtr
    HighestEndingAddress: VoidPtr
    Alignment: UIntPtr
MEM_DEDICATED_ATTRIBUTE_TYPE = Int32
MemDedicatedAttributeReadBandwidth: win32more.Windows.Win32.System.Memory.MEM_DEDICATED_ATTRIBUTE_TYPE = 0
MemDedicatedAttributeReadLatency: win32more.Windows.Win32.System.Memory.MEM_DEDICATED_ATTRIBUTE_TYPE = 1
MemDedicatedAttributeWriteBandwidth: win32more.Windows.Win32.System.Memory.MEM_DEDICATED_ATTRIBUTE_TYPE = 2
MemDedicatedAttributeWriteLatency: win32more.Windows.Win32.System.Memory.MEM_DEDICATED_ATTRIBUTE_TYPE = 3
MemDedicatedAttributeMax: win32more.Windows.Win32.System.Memory.MEM_DEDICATED_ATTRIBUTE_TYPE = 4
class MEM_EXTENDED_PARAMETER(Structure):
    Anonymous1: _Anonymous1_e__Struct
    Anonymous2: _Anonymous2_e__Union
    class _Anonymous1_e__Struct(Structure):
        Type: Annotated[UInt64, 8]
        Reserved: Annotated[UInt64, 56]
    class _Anonymous2_e__Union(Union):
        ULong64: UInt64
        Pointer: VoidPtr
        Size: UIntPtr
        Handle: win32more.Windows.Win32.Foundation.HANDLE
        ULong: UInt32
MEM_EXTENDED_PARAMETER_TYPE = Int32
MemExtendedParameterInvalidType: win32more.Windows.Win32.System.Memory.MEM_EXTENDED_PARAMETER_TYPE = 0
MemExtendedParameterAddressRequirements: win32more.Windows.Win32.System.Memory.MEM_EXTENDED_PARAMETER_TYPE = 1
MemExtendedParameterNumaNode: win32more.Windows.Win32.System.Memory.MEM_EXTENDED_PARAMETER_TYPE = 2
MemExtendedParameterPartitionHandle: win32more.Windows.Win32.System.Memory.MEM_EXTENDED_PARAMETER_TYPE = 3
MemExtendedParameterUserPhysicalHandle: win32more.Windows.Win32.System.Memory.MEM_EXTENDED_PARAMETER_TYPE = 4
MemExtendedParameterAttributeFlags: win32more.Windows.Win32.System.Memory.MEM_EXTENDED_PARAMETER_TYPE = 5
MemExtendedParameterImageMachine: win32more.Windows.Win32.System.Memory.MEM_EXTENDED_PARAMETER_TYPE = 6
MemExtendedParameterMax: win32more.Windows.Win32.System.Memory.MEM_EXTENDED_PARAMETER_TYPE = 7
MEM_SECTION_EXTENDED_PARAMETER_TYPE = Int32
MemSectionExtendedParameterInvalidType: win32more.Windows.Win32.System.Memory.MEM_SECTION_EXTENDED_PARAMETER_TYPE = 0
MemSectionExtendedParameterUserPhysicalFlags: win32more.Windows.Win32.System.Memory.MEM_SECTION_EXTENDED_PARAMETER_TYPE = 1
MemSectionExtendedParameterNumaNode: win32more.Windows.Win32.System.Memory.MEM_SECTION_EXTENDED_PARAMETER_TYPE = 2
MemSectionExtendedParameterSigningLevel: win32more.Windows.Win32.System.Memory.MEM_SECTION_EXTENDED_PARAMETER_TYPE = 3
MemSectionExtendedParameterMax: win32more.Windows.Win32.System.Memory.MEM_SECTION_EXTENDED_PARAMETER_TYPE = 4
OFFER_PRIORITY = Int32
VmOfferPriorityVeryLow: win32more.Windows.Win32.System.Memory.OFFER_PRIORITY = 1
VmOfferPriorityLow: win32more.Windows.Win32.System.Memory.OFFER_PRIORITY = 2
VmOfferPriorityBelowNormal: win32more.Windows.Win32.System.Memory.OFFER_PRIORITY = 3
VmOfferPriorityNormal: win32more.Windows.Win32.System.Memory.OFFER_PRIORITY = 4
PAGE_PROTECTION_FLAGS = UInt32
PAGE_NOACCESS: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS = 1
PAGE_READONLY: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS = 2
PAGE_READWRITE: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS = 4
PAGE_WRITECOPY: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS = 8
PAGE_EXECUTE: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS = 16
PAGE_EXECUTE_READ: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS = 32
PAGE_EXECUTE_READWRITE: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS = 64
PAGE_EXECUTE_WRITECOPY: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS = 128
PAGE_GUARD: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS = 256
PAGE_NOCACHE: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS = 512
PAGE_WRITECOMBINE: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS = 1024
PAGE_GRAPHICS_NOACCESS: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS = 2048
PAGE_GRAPHICS_READONLY: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS = 4096
PAGE_GRAPHICS_READWRITE: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS = 8192
PAGE_GRAPHICS_EXECUTE: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS = 16384
PAGE_GRAPHICS_EXECUTE_READ: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS = 32768
PAGE_GRAPHICS_EXECUTE_READWRITE: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS = 65536
PAGE_GRAPHICS_COHERENT: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS = 131072
PAGE_GRAPHICS_NOCACHE: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS = 262144
PAGE_ENCLAVE_THREAD_CONTROL: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS = 2147483648
PAGE_REVERT_TO_FILE_MAP: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS = 2147483648
PAGE_TARGETS_NO_UPDATE: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS = 1073741824
PAGE_TARGETS_INVALID: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS = 1073741824
PAGE_ENCLAVE_UNVALIDATED: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS = 536870912
PAGE_ENCLAVE_MASK: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS = 268435456
PAGE_ENCLAVE_DECOMMIT: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS = 268435456
PAGE_ENCLAVE_SS_FIRST: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS = 268435457
PAGE_ENCLAVE_SS_REST: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS = 268435458
SEC_PARTITION_OWNER_HANDLE: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS = 262144
SEC_64K_PAGES: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS = 524288
SEC_FILE: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS = 8388608
SEC_IMAGE: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS = 16777216
SEC_PROTECTED_IMAGE: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS = 33554432
SEC_RESERVE: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS = 67108864
SEC_COMMIT: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS = 134217728
SEC_NOCACHE: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS = 268435456
SEC_WRITECOMBINE: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS = 1073741824
SEC_LARGE_PAGES: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS = 2147483648
SEC_IMAGE_NO_EXECUTE: win32more.Windows.Win32.System.Memory.PAGE_PROTECTION_FLAGS = 285212672
PAGE_TYPE = UInt32
MEM_PRIVATE: win32more.Windows.Win32.System.Memory.PAGE_TYPE = 131072
MEM_MAPPED: win32more.Windows.Win32.System.Memory.PAGE_TYPE = 262144
MEM_IMAGE: win32more.Windows.Win32.System.Memory.PAGE_TYPE = 16777216
@winfunctype_pointer
def PBAD_MEMORY_CALLBACK_ROUTINE() -> Void: ...
class PROCESS_HEAP_ENTRY(Structure):
    lpData: VoidPtr
    cbData: UInt32
    cbOverhead: Byte
    iRegionIndex: Byte
    wFlags: UInt16
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Block: _Block_e__Struct
        Region: _Region_e__Struct
        class _Block_e__Struct(Structure):
            hMem: win32more.Windows.Win32.Foundation.HANDLE
            dwReserved: UInt32 * 3
        class _Region_e__Struct(Structure):
            dwCommittedSize: UInt32
            dwUnCommittedSize: UInt32
            lpFirstBlock: VoidPtr
            lpLastBlock: VoidPtr
@winfunctype_pointer
def PSECURE_MEMORY_CACHE_CALLBACK(Addr: VoidPtr, Range: UIntPtr) -> win32more.Windows.Win32.Foundation.BOOLEAN: ...
SECTION_FLAGS = UInt32
SECTION_ALL_ACCESS: win32more.Windows.Win32.System.Memory.SECTION_FLAGS = 983071
SECTION_QUERY: win32more.Windows.Win32.System.Memory.SECTION_FLAGS = 1
SECTION_MAP_WRITE: win32more.Windows.Win32.System.Memory.SECTION_FLAGS = 2
SECTION_MAP_READ: win32more.Windows.Win32.System.Memory.SECTION_FLAGS = 4
SECTION_MAP_EXECUTE: win32more.Windows.Win32.System.Memory.SECTION_FLAGS = 8
SECTION_EXTEND_SIZE: win32more.Windows.Win32.System.Memory.SECTION_FLAGS = 16
SECTION_MAP_EXECUTE_EXPLICIT: win32more.Windows.Win32.System.Memory.SECTION_FLAGS = 32
SETPROCESSWORKINGSETSIZEEX_FLAGS = UInt32
QUOTA_LIMITS_HARDWS_MIN_ENABLE: win32more.Windows.Win32.System.Memory.SETPROCESSWORKINGSETSIZEEX_FLAGS = 1
QUOTA_LIMITS_HARDWS_MIN_DISABLE: win32more.Windows.Win32.System.Memory.SETPROCESSWORKINGSETSIZEEX_FLAGS = 2
QUOTA_LIMITS_HARDWS_MAX_ENABLE: win32more.Windows.Win32.System.Memory.SETPROCESSWORKINGSETSIZEEX_FLAGS = 4
QUOTA_LIMITS_HARDWS_MAX_DISABLE: win32more.Windows.Win32.System.Memory.SETPROCESSWORKINGSETSIZEEX_FLAGS = 8
UNMAP_VIEW_OF_FILE_FLAGS = UInt32
MEM_UNMAP_NONE: win32more.Windows.Win32.System.Memory.UNMAP_VIEW_OF_FILE_FLAGS = 0
MEM_UNMAP_WITH_TRANSIENT_BOOST: win32more.Windows.Win32.System.Memory.UNMAP_VIEW_OF_FILE_FLAGS = 1
MEM_PRESERVE_PLACEHOLDER: win32more.Windows.Win32.System.Memory.UNMAP_VIEW_OF_FILE_FLAGS = 2
VIRTUAL_ALLOCATION_TYPE = UInt32
MEM_COMMIT: win32more.Windows.Win32.System.Memory.VIRTUAL_ALLOCATION_TYPE = 4096
MEM_RESERVE: win32more.Windows.Win32.System.Memory.VIRTUAL_ALLOCATION_TYPE = 8192
MEM_RESET: win32more.Windows.Win32.System.Memory.VIRTUAL_ALLOCATION_TYPE = 524288
MEM_RESET_UNDO: win32more.Windows.Win32.System.Memory.VIRTUAL_ALLOCATION_TYPE = 16777216
MEM_REPLACE_PLACEHOLDER: win32more.Windows.Win32.System.Memory.VIRTUAL_ALLOCATION_TYPE = 16384
MEM_LARGE_PAGES: win32more.Windows.Win32.System.Memory.VIRTUAL_ALLOCATION_TYPE = 536870912
MEM_RESERVE_PLACEHOLDER: win32more.Windows.Win32.System.Memory.VIRTUAL_ALLOCATION_TYPE = 262144
MEM_FREE: win32more.Windows.Win32.System.Memory.VIRTUAL_ALLOCATION_TYPE = 65536
VIRTUAL_FREE_TYPE = UInt32
MEM_DECOMMIT: win32more.Windows.Win32.System.Memory.VIRTUAL_FREE_TYPE = 16384
MEM_RELEASE: win32more.Windows.Win32.System.Memory.VIRTUAL_FREE_TYPE = 32768
WIN32_MEMORY_INFORMATION_CLASS = Int32
MemoryRegionInfo: win32more.Windows.Win32.System.Memory.WIN32_MEMORY_INFORMATION_CLASS = 0
class WIN32_MEMORY_PARTITION_INFORMATION(Structure):
    Flags: UInt32
    NumaNode: UInt32
    Channel: UInt32
    NumberOfNumaNodes: UInt32
    ResidentAvailablePages: UInt64
    CommittedPages: UInt64
    CommitLimit: UInt64
    PeakCommitment: UInt64
    TotalNumberOfPages: UInt64
    AvailablePages: UInt64
    ZeroPages: UInt64
    FreePages: UInt64
    StandbyPages: UInt64
    Reserved: UInt64 * 16
    MaximumCommitLimit: UInt64
    Reserved2: UInt64
    PartitionId: UInt32
WIN32_MEMORY_PARTITION_INFORMATION_CLASS = Int32
MemoryPartitionInfo: win32more.Windows.Win32.System.Memory.WIN32_MEMORY_PARTITION_INFORMATION_CLASS = 0
MemoryPartitionDedicatedMemoryInfo: win32more.Windows.Win32.System.Memory.WIN32_MEMORY_PARTITION_INFORMATION_CLASS = 1
class WIN32_MEMORY_RANGE_ENTRY(Structure):
    VirtualAddress: VoidPtr
    NumberOfBytes: UIntPtr
class WIN32_MEMORY_REGION_INFORMATION(Structure):
    AllocationBase: VoidPtr
    AllocationProtect: UInt32
    Anonymous: _Anonymous_e__Union
    RegionSize: UIntPtr
    CommitSize: UIntPtr
    class _Anonymous_e__Union(Union):
        Flags: UInt32
        Anonymous: _Anonymous_e__Struct
        class _Anonymous_e__Struct(Structure):
            Private: Annotated[UInt32, 1]
            MappedDataFile: Annotated[UInt32, 1]
            MappedImage: Annotated[UInt32, 1]
            MappedPageFile: Annotated[UInt32, 1]
            MappedPhysical: Annotated[UInt32, 1]
            DirectMapped: Annotated[UInt32, 1]
            Reserved: Annotated[UInt32, 26]


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Devices.Pwm
import win32more.Windows.Devices.Pwm.Provider
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Win32.System.WinRT
class IPwmController(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Pwm.IPwmController'
    _iid_ = Guid('{c45f5c85-d2e8-42cf-9bd6-cf5ed029e6a7}')
    @winrt_commethod(6)
    def get_PinCount(self) -> Int32: ...
    @winrt_commethod(7)
    def get_ActualFrequency(self) -> Double: ...
    @winrt_commethod(8)
    def SetDesiredFrequency(self, desiredFrequency: Double) -> Double: ...
    @winrt_commethod(9)
    def get_MinFrequency(self) -> Double: ...
    @winrt_commethod(10)
    def get_MaxFrequency(self) -> Double: ...
    @winrt_commethod(11)
    def OpenPin(self, pinNumber: Int32) -> win32more.Windows.Devices.Pwm.PwmPin: ...
    ActualFrequency = property(get_ActualFrequency, None)
    MaxFrequency = property(get_MaxFrequency, None)
    MinFrequency = property(get_MinFrequency, None)
    PinCount = property(get_PinCount, None)
class IPwmControllerStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Pwm.IPwmControllerStatics'
    _iid_ = Guid('{4263bda1-8946-4404-bd48-81dd124af4d9}')
    @winrt_commethod(6)
    def GetControllersAsync(self, provider: win32more.Windows.Devices.Pwm.Provider.IPwmProvider) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Devices.Pwm.PwmController]]: ...
class IPwmControllerStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Pwm.IPwmControllerStatics2'
    _iid_ = Guid('{44fc5b1f-f119-4bdd-97ad-f76ef986736d}')
    @winrt_commethod(6)
    def GetDefaultAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.Pwm.PwmController]: ...
class IPwmControllerStatics3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Pwm.IPwmControllerStatics3'
    _iid_ = Guid('{b2581871-0229-4344-ae3f-9b7cd0e66b94}')
    @winrt_commethod(6)
    def GetDeviceSelector(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def GetDeviceSelectorFromFriendlyName(self, friendlyName: WinRT_String) -> WinRT_String: ...
    @winrt_commethod(8)
    def FromIdAsync(self, deviceId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.Pwm.PwmController]: ...
class IPwmPin(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    _classid_ = 'Windows.Devices.Pwm.IPwmPin'
    _iid_ = Guid('{22972dc8-c6cf-4821-b7f9-c6454fb6af79}')
    @winrt_commethod(6)
    def get_Controller(self) -> win32more.Windows.Devices.Pwm.PwmController: ...
    @winrt_commethod(7)
    def GetActiveDutyCyclePercentage(self) -> Double: ...
    @winrt_commethod(8)
    def SetActiveDutyCyclePercentage(self, dutyCyclePercentage: Double) -> Void: ...
    @winrt_commethod(9)
    def get_Polarity(self) -> win32more.Windows.Devices.Pwm.PwmPulsePolarity: ...
    @winrt_commethod(10)
    def put_Polarity(self, value: win32more.Windows.Devices.Pwm.PwmPulsePolarity) -> Void: ...
    @winrt_commethod(11)
    def Start(self) -> Void: ...
    @winrt_commethod(12)
    def Stop(self) -> Void: ...
    @winrt_commethod(13)
    def get_IsStarted(self) -> Boolean: ...
    Controller = property(get_Controller, None)
    IsStarted = property(get_IsStarted, None)
    Polarity = property(get_Polarity, put_Polarity)
class PwmController(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.Pwm.IPwmController
    _classid_ = 'Windows.Devices.Pwm.PwmController'
    @winrt_mixinmethod
    def get_PinCount(self: win32more.Windows.Devices.Pwm.IPwmController) -> Int32: ...
    @winrt_mixinmethod
    def get_ActualFrequency(self: win32more.Windows.Devices.Pwm.IPwmController) -> Double: ...
    @winrt_mixinmethod
    def SetDesiredFrequency(self: win32more.Windows.Devices.Pwm.IPwmController, desiredFrequency: Double) -> Double: ...
    @winrt_mixinmethod
    def get_MinFrequency(self: win32more.Windows.Devices.Pwm.IPwmController) -> Double: ...
    @winrt_mixinmethod
    def get_MaxFrequency(self: win32more.Windows.Devices.Pwm.IPwmController) -> Double: ...
    @winrt_mixinmethod
    def OpenPin(self: win32more.Windows.Devices.Pwm.IPwmController, pinNumber: Int32) -> win32more.Windows.Devices.Pwm.PwmPin: ...
    @winrt_classmethod
    def GetDeviceSelector(cls: win32more.Windows.Devices.Pwm.IPwmControllerStatics3) -> WinRT_String: ...
    @winrt_classmethod
    def GetDeviceSelectorFromFriendlyName(cls: win32more.Windows.Devices.Pwm.IPwmControllerStatics3, friendlyName: WinRT_String) -> WinRT_String: ...
    @winrt_classmethod
    def FromIdAsync(cls: win32more.Windows.Devices.Pwm.IPwmControllerStatics3, deviceId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.Pwm.PwmController]: ...
    @winrt_classmethod
    def GetDefaultAsync(cls: win32more.Windows.Devices.Pwm.IPwmControllerStatics2) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.Pwm.PwmController]: ...
    @winrt_classmethod
    def GetControllersAsync(cls: win32more.Windows.Devices.Pwm.IPwmControllerStatics, provider: win32more.Windows.Devices.Pwm.Provider.IPwmProvider) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Devices.Pwm.PwmController]]: ...
    ActualFrequency = property(get_ActualFrequency, None)
    MaxFrequency = property(get_MaxFrequency, None)
    MinFrequency = property(get_MinFrequency, None)
    PinCount = property(get_PinCount, None)
class PwmPin(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Windows.Devices.Pwm.IPwmPin
    _classid_ = 'Windows.Devices.Pwm.PwmPin'
    @winrt_mixinmethod
    def get_Controller(self: win32more.Windows.Devices.Pwm.IPwmPin) -> win32more.Windows.Devices.Pwm.PwmController: ...
    @winrt_mixinmethod
    def GetActiveDutyCyclePercentage(self: win32more.Windows.Devices.Pwm.IPwmPin) -> Double: ...
    @winrt_mixinmethod
    def SetActiveDutyCyclePercentage(self: win32more.Windows.Devices.Pwm.IPwmPin, dutyCyclePercentage: Double) -> Void: ...
    @winrt_mixinmethod
    def get_Polarity(self: win32more.Windows.Devices.Pwm.IPwmPin) -> win32more.Windows.Devices.Pwm.PwmPulsePolarity: ...
    @winrt_mixinmethod
    def put_Polarity(self: win32more.Windows.Devices.Pwm.IPwmPin, value: win32more.Windows.Devices.Pwm.PwmPulsePolarity) -> Void: ...
    @winrt_mixinmethod
    def Start(self: win32more.Windows.Devices.Pwm.IPwmPin) -> Void: ...
    @winrt_mixinmethod
    def Stop(self: win32more.Windows.Devices.Pwm.IPwmPin) -> Void: ...
    @winrt_mixinmethod
    def get_IsStarted(self: win32more.Windows.Devices.Pwm.IPwmPin) -> Boolean: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
    Controller = property(get_Controller, None)
    IsStarted = property(get_IsStarted, None)
    Polarity = property(get_Polarity, put_Polarity)
class PwmPulsePolarity(Enum, Int32):
    ActiveHigh = 0
    ActiveLow = 1


make_ready(__name__)
